@@ -7,8 +7,7 @@ from .utils import with_opt
 
 class SymNets(BaseGCAdapter):
     """
-    Extends [BaseGCAdapter][pytorch_adapt.adapters.base_adapter.BaseGCAdapter]
-    and wraps [SymNetsHook][pytorch_adapt.hooks.SymNetsHook].
+    Wraps [SymNetsHook][pytorch_adapt.hooks.SymNetsHook].
 
     |Container|Required keys|
     |---|---|
@@ -20,9 +19,9 @@ class SymNets(BaseGCAdapter):
 
     hook_cls = SymNetsHook
 
-    def __init__(self, inference_fn=None, **kwargs):
+    def __init__(self, *args, inference_fn=None, **kwargs):
         inference_fn = c_f.default(inference_fn, symnets_fn)
-        super().__init__(inference_fn=inference_fn, **kwargs)
+        super().__init__(*args, inference_fn=inference_fn, **kwargs)
 
     def init_hook(self, hook_kwargs):
         self.hook = self.hook_cls(
